pub enum Restructure {
InsertRows {
at: usize,
count: usize,
},
DeleteRows {
at: usize,
count: usize,
},
InsertColumns {
at: usize,
count: usize,
},
DeleteColumns {
at: usize,
count: usize,
},
}Expand description
What is asked of a sheet.
Variants
InsertRows
Put count empty rows in before the row at at.
DeleteRows
Take count rows out, from the row at at.
InsertColumns
Put count empty columns in before the column at at.
DeleteColumns
Take count columns out, from the column at at.