split_keeping_item

Function split_keeping_item 

pub fn split_keeping_item(
    root: &mut Element,
    path: &[usize],
    at: usize,
) -> Result<Vec<usize>, Refused>
Split a paragraph in two as split_at does, but never take an empty item out of its list: what a paste needs, where Enter on an empty item is the way out of one.

Errors

The path leads to nothing, or to something that is not a paragraph.